"use strict";
/*
 * Copyright 2019 Amazon.com, Inc. or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsoleSink = void 0;
const console_1 = require("console");
const LogSerializer_1 = require("../serializers/LogSerializer");
/**
 * A sink that flushes log data to stdout.
 * This is the preferred sink for Lambda functions.
 */
class ConsoleSink {
    constructor(serializer) {
        this.name = 'ConsoleSink';
        this.serializer = serializer || new LogSerializer_1.LogSerializer();
        // To avoid escaping EMF when using Lambda JSON log format we need to use Console() instead of console
        this.console =
            process.env[ConsoleSink.AWS_LAMBDA_LOG_FORMAT] === 'JSON' ? new console_1.Console(process.stdout, process.stderr) : console;
    }
    accept(context) {
        // tslint:disable-next-line
        const events = this.serializer.serialize(context);
        events.forEach((event) => this.console.log(event));
        return Promise.resolve();
    }
}
exports.ConsoleSink = ConsoleSink;
ConsoleSink.AWS_LAMBDA_LOG_FORMAT = 'AWS_LAMBDA_LOG_FORMAT';
