import { Unit } from '../logger/Unit';
import { StorageResolution } from '../logger/StorageResolution';
/**
 * Validates dimension set.
 * @see [CloudWatch Dimensions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Dimension.html)
 *
 * @param dimensionSet
 * @throws {DimensionSetExceededError} Dimension set must not exceed 30 dimensions.
 * @throws {InvalidDimensionError} Dimension name and value must be valid.
 */
declare const validateDimensionSet: (dimensionSet: Record<string, string>) => void;
/**
 * Validates metric.
 * @see [CloudWatch Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html)
 *
 * @param key
 * @param value
 * @param unit
 * @param storageResolution
 *
 * @throws {InvalidMetricError} Metric name must be valid.
 */
declare const validateMetric: (key: string, value: number, unit?: Unit | string, storageResolution?: StorageResolution, metricNameAndResolutionMap?: Map<string, StorageResolution>) => void;
/**
 * Validates metric namespace.
 * @see [CloudWatch Namespace](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Namespace)
 *
 * @param namespace
 * @throws {InvalidNamespaceError} Namespace must be of valid length.
 */
declare const validateNamespace: (namespace: string) => void;
/**
 * Validates timestamp.
 * @see [CloudWatch Timestamp](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#about_timestamp)
 *
 * @param timestamp
 */
declare const validateTimestamp: (timestamp: Date | number) => void;
export { validateDimensionSet, validateMetric, validateNamespace, validateTimestamp };
